@@ -28,6 +28,7 @@ static int apessidcount;
 static int thisyear;
 
 static bool netgearflag;
+static bool digit10flag;
 static bool phomeflag;
 static bool tendaflag;
 static bool weakpassflag;
@@ -93,6 +94,45 @@ if((lowerpskstring[0] >= 'a') && (lowerpskstring[0] <= 'z'))
 return;
 }
 /*===========================================================================*/
+static void keywritedigit10(FILE *fhout)
+{
+static int i;
+static uint16_t f1, f2;
+static unsigned long long int ec, el, eu;
+static MD5_CTX ctxmd5;
+static char saltstring[64];
+static unsigned char digestmd5[MD5_DIGEST_LENGTH];
+
+static uint32_t fixseed1[] =
+{
+0xb100, 0xb300, 0xf200, 0xf800, 0xf900, 0xfa00
+};
+#define FIXSEED1_SIZE sizeof(fixseed1) /sizeof(uint32_t)
+
+for(f1 = 0; f1 < FIXSEED1_SIZE; f1++)
+	{
+	for(f2 = 0; f2 <=0xff; f2++)
+		{
+		for(ec = 0; ec <= 0xffff; ec++)
+			{
+			snprintf(saltstring, 64, "D0542D-01%010lld", ec | (fixseed1[f1] +f2) << 16);
+			MD5_Init(&ctxmd5);
+			MD5_Update(&ctxmd5, saltstring, 19);
+			MD5_Final(digestmd5, &ctxmd5);
+			el = 0;
+			eu = 0;
+			for(i = 0; i < 8; i++)
+				{
+				eu = (el >> 0x18 | ((eu << 8) &0xffffffff)) &0xffffffff;
+				el = (((el << 8) &0xffffffff) | digestmd5[i + 8]) &0xffffffff;
+				}
+			fprintf(fhout, "%010lld\n", ((eu << 32) +el) %0x2540be400);
+			}
+		}
+	}
+return;
+}
+/*===========================================================================*/
 static void keywritenetgear(FILE *fhout)
 {
 static size_t ca, cs;
@@ -100,83 +140,95 @@ static int cn;
 
 static char pskstring[PSKSTRING_LEN_MAX] = {};
 
-static const char *adjectiv[] = { "absurd", "ancient", "antique", "aquatic",
-	"baby", "basic", "bay", "better", "big", "bitter", "black", "blue", "bold", "bottled", "brave", "breezy", "bright", "brown",
-	"calm", "camera", "carrot", "cash", "charming", "cheerful", "chilly", "chip", "chummy", "classy", "clean", "clear", "clever", "cloudy", "cold", "cool", "crispy", "curly",
-	"daily", "deep", "delightful", "dizzy", "down", "dynamic",
-	"east", "elated", "elegant", "excite", "excited", "exotic",
-	"famous", "fancy", "fearless", "festive", "fluffy", "free", "fresh", "friendly", "funny", "fuzzy",
-	"gentle", "gifted", "gigantic", "global", "good", "graceful", "grand", "great", "green",
-	"happy", "heavy", "helpful", "hot", "hungry", "husky",
-	"icy", "imaginary", "invent", "invisible",
-	"jacket", "jagged", "jolly", "joyful", "joyous",
-	"kind",
-	"large", "left", "light", "lime", "little", "lively", "lovely", "lucky", "lumpy",
-	"magical", "major", "manic", "mellow", "melodic", "mighty", "misty", "modern",
-	"narrow", "nest", "new", "nice", "nifty", "noisy", "normal",
-	"occur", "ocean", "odd", "old", "orange", "ordinary",
-	"painless", "parade", "pass", "pastel", "peaceful", "perfect", "phobic", "phone", "pink", "plain", "polite", "poor", "precious", "pretty", "purple",
-	"quaint", "quick", "quiet",
-	"rain", "rapid", "red", "rocky", "rough", "round", "royal", "rustic",
-	"safe", "salute", "sandy", "sharp", "shiny", "short", "silent", "silky", "silly", "slender", "slow", "slower", "small", "smart", "smiley", "smiling", "smooth", "snug", "soft", "sour", "strange", "strong", "sunny", "super", "sweet", "swift",
-	"tablet", "terrific", "thirsty", "thoughtful", "tiny",
-	"uneven", "unusual", "urban",
-	"vanilla", "vast", "violet"
-	"warm", "watery", "weak", "white", "wide", "wild", "wilde", "windy", "wise", "witty", "wonderful",
+static const char *firstword[] = { "absurd", "agency", "ago", "album", "ancient", "anchor", "antique", "aquatic", "author",
+	"baby", "bakery", "basic", "bay", "better", "big", "bitter", "black", "blue", "bold", "botany", "bottled", "brave",
+	"breezy", "bridge", "brief", "bright", "brown",
+	"cable", "calm", "camera", "carrot", "cash", "charming", "cheerful", "chilly", "chip", "chorus", "chummy", "classy", "clean",
+	"clear", "clever", "cloudy", "clumsy", "cold", "comet", "cool", "crispy", "curly",
+	"daily", "deep", "delightful", "dizzy", "down", "dusty", "dynamic",
+	"eager", "east", "elated", "elegant", "emigrant", "energy", "engine", "every", "excite", "excited", "exotic", "eye",
+	"famous", "fancy", "fast", "fearless", "festive", "few", "finish", "fit", "fluent", "fluffy", "formal", "free", "fresh", "friendly", "funny", "fuzzy",
+	"gallon", "gentle", "gifted", "gigantic", "global", "good", "graceful", "grand", "great", "green",
+	"happy", "harbor", "heavy", "height", "helpful", "honor", "hot", "hotel", "hungry", "husky", "hybrid",
+	"icy", "idea", "imaginary", "invent", "invisible", "immune",
+	"jacket", "jagged", "jazz", "jewel", "jolly", "joyful", "joyous",
+	"key", "kind", "kite", 
+	"ladder", "large", "leader", "left", "lens", "light", "lime", "little", "lively", "locky", "lovely", "lucky", "lumpy",
+	"magical", "major", "manic", "mellow", "melodic", "middle", "mighty", "mirror", "misty", "mobile", "modern", "month", 
+	"narrow", "nest", "new", "nice", "nifty", "noisy", "normal", "north",
+	"oasis", "object", "occur", "ocean", "odd", "old", "only", "orange", "ordinary",
+	"painless", "palm", "parade", "pass", "pastel", "peaceful", "perfect", "period", "phobic", "phone", "pink", "plain", "pledge", "pocket", "polite",
+	"poor", "praise", "precious", "pretty", "prose", "purple",
+	"quaint", "quick", "quiet", "quote",
+	"rain", "rapid", "red", "remote", "rocky", "rough", "round", "royal", "runner", "rustic",
+	"safe", "safety", "salute", "sandy", "sharp", "shiny", "short", "silent", "silky", "silly", "slender", "slow",
+	"slower", "small", "smart", "smiley", "smiling", "smooth", "snug", "soft", "sour", "spirit", "stealth","still", "strange", "strong",
+	"summit", "sunny", "super", "sweet", "swift", "swing",
+	"tablet", "teal", "terrific", "thirsty", "thoughtful", "timber", "tiny", "top", "town",
+	"uneven", "union", "unusual", "urban", "useful",
+	"vanilla", "vast", "verse", "violet", "violin",
+	"walnut", "warm", "watch", "watery", "weak", "west", "white", "wide", "wild", "wilde", "windy", "wise", "witty", "wonderful", "worth",
 	"yellow", "young",
-	"zany" };
+	"zany", "zeal", "zebra" };
 
-static const char *substantiv[] = { "airplane", "album", "apple", "automobile",
-	"ball", "balloon", "banana", "beach", "bead", "berry", "bike", "bird", "boat", "bolt", "book", "boot", "bottle", "box", "brain", "bread", "breeze", "bridge", "bubble", "bug", "bunny", "bush", "butter",
-	"canoe", "car", "carrot", "cartoon", "cello", "chair", "chat", "cheese", "chill", "chip", "coast", "coconut", "comet", "cream", "crown", "curly", "curtain",
-	"daisy", "deal", "deer", "desk", "diamond", "dink", "doll", "domain", "door",
-	"earth", "elephant", "emerald",
-	"finch", "fire", "fish", "flamingo", "flower", "flute", "forest",
-	"gadfly", "gate", "gear", "giant", "giraffe", "girl", "glove", "grape", "grasshopper", "guppy",
-	"hair", "hand", "hat", "hill", "hippo", "house",
-	"ink", "iris",
-	"jade", "jet", "jetcar", "jungle",
-	"kangaroo", "kayak", "knight", 
-	"lake", "lemon", "light", "lightning", "lion", "lotus", "lump",
-	"mango", "mesa", "mint", "monkey", "moon", "motorcycle", "mountain",
-	"ness", "nest",
-	"oboe", "ocean", "octopus", "onion", "orange", "orchestra", "owl",
-	"panda", "pant", "parade", "path", "pear", "pencil", "penguin", "phrase", "phoenix", "piano", "pineapple", "planet", "plum", "pond", "poodle", "potato", "prairie",
-	"quail",
-	"rabbit", "raccoon", "raid", "rain", "raven", "reason", "review", "river", "road", "rock", "robert", "rosebud", "ruby",
-	"sea", "seed", "shark", "sheep", "ship", "shoe", "shore", "shrub", "side", "silver", "sitter", "skates", "skin", "sky", "snail", "snake", "socks", "spark", "sparrow", "spider", "squash", "squirrel", "star", "state", "stream", "street", "studio", "sun",
-	"table", "tablet", "teapot", "terrain", "theory", "tiger", "toast", "tomato", "town", "trail", "train", "tree", "truck", "trumpet", "tuba", "tulip", "turkey",
-	"umbrella", "unicorn", "unit", "useful",
-	"valley", "vase", "violet", "violin",
-	"wagon", "water", "whale", "west", "wind", "window", "windy",
-	"yard",
-	"zebra", "zoo" };
+static const char *secondword[] = { "absent", "acre", "agency", "airplane", "album", "ape", "apple", "automobile",
+	"ball", "balloon", "banana", "beach", "bead", "bench", "berry", "bike", "bird", "boat", "bolt", "book", "boot", "botany", "both",
+	"bottle", "box", "brain", "bread", "breeze", "bridge", "bubble", "bug", "bunny", "bush", "butter",
+	"canoe", "car", "cat", "carrot", "cartoon", "cello", "chair", "chat", "cheese", "chill", "chip", "city", "coast", "coconut", "comet",
+	"cream", "crown", "curly", "curtain",
+	"daisy", "deal", "deer", "desk", "diamond", "dink", "dog", "doll", "domain", "door",
+	"eagle", "earth", "elephant", "emerald", "energy", "epic",
+	"farmer", "field", "finch", "finish", "fire", "fish", "flamingo", "floor", "flower", "fluent", "flute", "forest", "formal", "free", "friend",
+	"fruit",
+	"gadfly", "gate", "gear", "giant", "giraffe", "girl", "global", "glove", "grain", "grape", "grasshopper", "guppy", "guitar",
+	"hair", "hall", "hand", "hat", "hill", "hippo", "horse", "hotel", "house",
+	"idea", "immune", "ink", "iris", "island",
+	"jade", "jazz", "jeans", "jet", "jetcar", "jungle",
+	"kangaroo", "kayak", "key", "kite", "knight",
+	"lake", "lawn", "leader", "lemon", "light", "lightning", "lion", "lotus", "lump",
+	"mode", "mango", "menu", "mesa", "mint", "monkey", "month", "moon", "motorcycle", "mountain", "museum",
+	"ness", "nest", "noble",
+	"oasis", "object", "oboe", "ocean", "octopus", "onion", "orange", "orchestra", "owl", "oxygen", 
+	"panda", "pant", "paper", "parade", "park", "path", "patron", "pear", "pencil", "penguin", "phrase", "phoenix", "piano", "pineapple",
+	"place", "plane", "planet", "pledge", "plum", "pocket", "poetry", "pond", "poodle", "potato", "prairie", "prose",
+	"quail", "quaint", "quick", "quote",
+	"rabbit", "raccoon", "raft", "raid", "rain", "raven", "reason", "remedy", "review", "reward", "river", "road", "rock", "robert", "rosebud",
+	"ruby", "runner",
+	"safety", "sea", "seed", "shark", "sheep", "shelf", "ship", "shoe", "shore", "shrub", "side", "silver", "sitter", "skates", "skin", "sky", "sled",
+	"snail", "snake", "soccer", "socks", "space", "spark", "sparrow", "spider", "squash", "squirrel", "stable", "star", "state", "statue", "stove",
+	"stream", "street", "studio", "sun",
+	"table", "tablet", "teapot", "tent", "terrain", "theory", "tiger", "toast", "tomato", "tooth", "town", "trail", "train", "tree", "truck",
+	"trumpet", "tuba", "tulip", "turkey", "turtle",
+	"umbrella", "unicorn", "union", "unit", "useful",
+	"vacant", "valley", "vase", "verse", "violet", "violin",
+	"wagon", "wall", "walnut", "water", "whale", "wealth", "west", "wind", "window", "windy",
+	"yard", "year",
+	"zeal", "zebra", "zoo" };
 
-for(ca = 0; ca < (sizeof(adjectiv) / sizeof(char *)); ca++)
+for(ca = 0; ca < (sizeof(firstword) / sizeof(char *)); ca++)
 	{
-	for(cs = 0; cs < (sizeof(substantiv) / sizeof(char *)); cs++)
+	for(cs = 0; cs < (sizeof(secondword) / sizeof(char *)); cs++)
 		{
-		if(strcmp(adjectiv[ca], substantiv[cs]) == 0) continue;
-		snprintf(pskstring, 64, "%s%s", adjectiv[ca], substantiv[cs]);
+		if(strcmp(firstword[ca], secondword[cs]) == 0) continue;
+		snprintf(pskstring, 64, "%s%s", firstword[ca], secondword[cs]);
 		fprintf(fhout,"%s\n", pskstring);
 		for (cn = 0; cn < 1000; cn++)
 			{
-			snprintf(pskstring, 64, "%s%s%d", adjectiv[ca], substantiv[cs], cn);
+			snprintf(pskstring, 64, "%s%s%d", firstword[ca], secondword[cs], cn);
 			fprintf(fhout,"%s\n", pskstring);
 			if(cn < 10)
 				{
-				snprintf(pskstring, 64, "%s%s%02d", adjectiv[ca], substantiv[cs], cn);
+				snprintf(pskstring, 64, "%s%s%02d", firstword[ca], secondword[cs], cn);
 				fprintf(fhout,"%s\n", pskstring);
 				}
 			if(cn < 100)
 				{
-				snprintf(pskstring, 64, "%s%s%03d", adjectiv[ca], substantiv[cs], cn);
+				snprintf(pskstring, 64, "%s%s%03d", firstword[ca], secondword[cs], cn);
 				fprintf(fhout,"%s\n", pskstring);
 				}
 			}
 		}
 	}
-
 return;
 }
 /*===========================================================================*/
@@ -198,9 +250,9 @@ static const char *five[] = {"about", "again", "aisle", "alley", "amaze", "apron
 	};
 
 static const char *six[] = {"action", "always", "animal", "answer", "anyone", "appear", "arctic", "autumn",
-	"basket", "beside", "better", "bottle", "breezy", "bridge", "button", 
+	"basket", "beside", "better", "bottle", "breezy", "bridge", "button",
 	"cactus", "called", "camera", "candid", "canvas", "canyon", "castle", "cattle", "caught", "celery", "cellar",
-	"change", "charge", "cheery", "chores", "chosen", "circle", "cities", "comedy", "copied", "county", "create", 
+	"change", "charge", "cheery", "chores", "chosen", "circle", "cities", "comedy", "copied", "county", "create",
 	"degree", "depend", "detail", "dimmed", "dinner", "direct",
 	"effect", "eighty", "eleven",
 	"factir", "famous", "filter", "finish", "flower", "follow", "forest",
@@ -519,6 +571,7 @@ static int ek;
 static char *ev;
 
 static char essidtmp[PSKSTRING_LEN_MAX] = {};
+
 if(essidlen >= 4)
 	{
 	if((isxdigit(essid[essidlen -4])) && (isxdigit(essid[essidlen -3])) && (isxdigit(essid[essidlen -2])) && (isxdigit(essid[essidlen -1])))
@@ -828,6 +881,29 @@ for(k1 = 0; k1 < 10000; k1++)
 return;
 }
 /*===========================================================================*/
+static void testarrisizzi(FILE *fhout, uint8_t essidlen, uint8_t *essid)
+{
+static int c;
+static uint32_t i;
+static char *izzi = "IZZI-";
+
+static int fixseed2[] =
+{
+0x001C15, 0x189C27, 0x3C0461, 0x509551, 0x704FB8, 0x8871B1, 0x8C61A3, 0x9CC8FC,
+0xA811FC, 0xD4AB82, 0xF0AF85, 0xF82DC0, 0xF88B37, 0xF8F532, 0xFCAE34
+};
+#define FIXSEED2_SIZE sizeof(fixseed2) /sizeof(int)
+
+if(essidlen < 9) return;
+if(memcmp(essid, izzi, 5) != 0) return;
+if((!isxdigit(essid[5])) || (!isxdigit(essid[6])) || (!isxdigit(essid[7])) || (!isxdigit(essid[8]))) return;
+for(i = 0; i < FIXSEED2_SIZE; i++)
+	{
+	for(c = 0; c < 0x100; c++) fprintf(fhout, "%06X%02X%C%C%C%C\n", fixseed2[i], c, essid[5], essid[6], essid[7], essid[8]);
+	}
+return;
+}
+/*===========================================================================*/
 static void testarristg(FILE *fhout, uint8_t essidlen, uint8_t *essid)
 {
 static int k1;
@@ -1175,6 +1251,29 @@ if(essidlen >= 9)
 return;
 }
 /*===========================================================================*/
+static void testtelered(FILE *fhout, uint8_t essidlen, uint8_t *essid)
+{
+static uint32_t i;
+static int c;
+static const char *telered = "TeleRed-";
+
+static uint32_t fix[] =
+{
+0x324b, 0x96e6, 0x9c67, 0xa266, 0xcfe2
+};
+#define FIX_SIZE sizeof(fix) /sizeof(int)
+
+if(essidlen < 12) return;
+if(memcmp(essid, telered, 8) != 0) return;
+if((!isxdigit(essid[8])) || (!isxdigit(essid[9])) || (!isxdigit(essid[10])) || (!isxdigit(essid[11]))) return;
+
+for(i = 0; i < FIX_SIZE; i++)
+	{
+	for(c = 0; c < 0x100; c++) fprintf(fhout, "%04X%02X%C%C%C%C\n", fix[i], c, essid[8], essid[9], essid[10], essid[11]);
+	}
+return;
+}
+/*===========================================================================*/
 static void testukrtelecom(FILE *fhout, uint8_t essidlen, uint8_t *essid)
 {
 static int k;
@@ -1276,6 +1375,7 @@ static char essidtmp[PSKSTRING_LEN_MAX] = {};
 
 if((essidlen == 0) || (essidlen > 32)) return;
 testalcatellinkzone(fhout, essidlen, essid);
+testarrisizzi(fhout, essidlen, essid);
 testarristg(fhout, essidlen, essid);
 testattwifi(fhout, essidlen, essid);
 testaxtelxtremo(fhout, essidlen, essid);
@@ -1288,6 +1388,7 @@ testmywifi(fhout, essidlen, essid);
 testroamingman(fhout, essidlen, essid);
 testrtk(fhout, essidlen, essid);
 testtechnicolor(fhout, essidlen, essid);
+testtelered(fhout, essidlen, essid);
 testukrtelecom(fhout, essidlen, essid);
 testwifirsu(fhout, essidlen, essid);
 testwlan(fhout, essidlen, essid);
@@ -1518,6 +1619,7 @@ return;
 static void processadditionals(FILE *fhout)
 {
 if(netgearflag == true) keywritenetgear(fhout);
+if(digit10flag == true) keywritedigit10(fhout);
 if(phomeflag == true) keywritephome(fhout);
 if(tendaflag == true)
 	{
@@ -1918,15 +2020,16 @@ printf("%s %s (C) %s ZeroBeat\n"
 	"-h          : show this help\n"
 	"-v          : show version\n"
 	"\n"
-	"--netgear : include weak NETGEAR candidates\n"
-	"--phome   : include weak PEGATRON HOME candidates\n"
-	"--tenda   : include weak TENDA candidates\n"
-	"--weakpass: include weak password candidates\n"
-	"--eudate  : include complete european dates\n"
-	"--usdate  : include complete american dates\n"
-	"--wpskeys : include complete WPS keys\n"
-	"--help    : show this help\n"
-	"--version : show version\n"
+	"--netgear     : include weak NETGEAR candidates\n"
+	"--digit10     : include weak 10 digit candidates (INFINITUM, ALHN, INEA)\n"
+	"--phome       : include weak PEGATRON HOME candidates\n"
+	"--tenda       : include weak TENDA candidates\n"
+	"--weakpass    : include weak password candidates\n"
+	"--eudate      : include complete european dates\n"
+	"--usdate      : include complete american dates\n"
+	"--wpskeys     : include complete WPS keys\n"
+	"--help        : show this help\n"
+	"--version     : show version\n"
 	"\n"
 	"if hcxpsktool recovered your password, you should change it immediately!\n"
 	"\n"
@@ -1961,6 +2064,7 @@ static char *macapname = NULL;
 static char *pskname = NULL;
 
 netgearflag = false;
+digit10flag = false;
 phomeflag = false;
 tendaflag = false;
 weakpassflag = false;
@@ -1974,6 +2078,7 @@ static const char *short_options = "c:i:j:z:o:e:b:o:hv";
 static const struct option long_options[] =
 {
 	{"netgear",			no_argument,		NULL,	HCXD_NETGEAR},
+	{"digit10",			no_argument,		NULL,	HCXD_DIGIT10},
 	{"phome",			no_argument,		NULL,	HCXD_PHOME},
 	{"tenda",			no_argument,		NULL,	HCXD_TENDA},
 	{"weakpass",			no_argument,		NULL,	HCXD_WEAKPASS},
@@ -1997,6 +2102,10 @@ while((auswahl = getopt_long (argc, argv, short_options, long_options, &index))
 		netgearflag = true;
 		break;
 
+		case HCXD_DIGIT10:
+		digit10flag = true;
+		break;
+
 		case HCXD_PHOME:
 		phomeflag = true;
 		break;
