@@ -330,22 +330,32 @@ struct vendorie_tag
 {
  uint8_t		oui[3];
  uint8_t		ouitype;
-#define	VT_WPA_IE	1
-#define	VT_WMM_IE	2
-#define	VT_WPS_IE	4
+#define	VT_WPA_IE	0x01
+#define	VT_RSN_IE	0x02
+#define	VT_WMM_IE	0x02
+#define	VT_WPS_IE	0x04
+#define	VT_AWDL_IE	0x08
+#define	VT_NAN_IE	0x13
  uint8_t		data[1];
 } __attribute__ ((packed));
 typedef struct vendorie_tag vendorie_t;
 #define	VENDORIE_SIZE offsetof(vendorie_t, data)
 
-static const uint8_t mscorp[3] =
+static const uint8_t ouimscorp[3] =
 {
 0x00, 0x50, 0xf2
 };
+static const uint8_t ouiapple[3] =
+{
+0x00, 0x17, 0xf2
+};
+static const uint8_t ouiwifialliance[3] =
+{
+0x50, 0x6f, 0x9a
+};
 /*===========================================================================*/
 struct rsnie_tag
 {
-#define	VT_RSN_IE	2
  uint16_t		version;
  uint8_t		data[1];
 } __attribute__((__packed__));
@@ -358,7 +368,6 @@ struct wpaie_tag
  uint8_t		oui[3];
  uint8_t		ouitype;
  uint16_t		type;
-#define	VT_WPA_IE	1
  uint8_t		data[1];
 } __attribute__ ((packed));
 typedef struct wpaie_tag wpaie_t;
@@ -493,17 +502,26 @@ typedef struct association_resp_frame assocrepf_t;
 struct action_frame
 {
  uint8_t	categoriecode;
-#define CAT_BLOCK_ACK		3
-#define CAT_RADIO_MEASUREMENT		5
+#define CAT_BLOCK_ACK			0x03
+#define CAT_RADIO_MEASUREMENT		0x05
+#define CAT_VENDOR			0x7f
  uint8_t	actioncode;
-#define ACT_ADD_BLOCK_ACK_REQ		0
-#define ACT_ADD_BLOCK_ACK_RESP		0
-#define ACT_DELETE_BLOCK_REQ		2
-#define ACT_RADIO_MEASUREMENT_REQ	0
+#define ACT_ADD_BLOCK_ACK_REQ		0x00
+#define ACT_ADD_BLOCK_ACK_RESP		0x00
+#define ACT_DELETE_BLOCK_REQ		0x02
+#define ACT_RADIO_MEASUREMENT_REQ	0x00
 };
 typedef struct action_frame actf_t;
 #define ACTIONFRAME_SIZE (sizeof(actf_t))
 /*===========================================================================*/
+struct actionvendor_frame
+{
+ uint8_t	categoriecode;
+ uint8_t	vendor[3];
+};
+typedef struct actionvendor_frame actvf_t;
+#define ACTIONVENDORFRAME_SIZE (sizeof(actvf_t))
+/*===========================================================================*/
 struct eapauthentication_s
 {
  uint8_t		version;
